@@ -19,12 +19,9 @@
 """
 
 # System imports
-import os
-import sys
 import argparse
 
 # Keras imports
-import tensorflow.keras.backend as K
 from tensorflow.keras.datasets import cifar10
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.callbacks import LearningRateScheduler, EarlyStopping
@@ -58,13 +55,17 @@ def get_rescaled_data_set(a, b):
     return x_train, y_train, x_test, y_test
 
 
-def train_model(model,
-                x_train,
-                y_train,
-                x_test,
-                y_test,
-                batch_size=500,
-                epochs=1000):
+def compile_model(model, learning_rate):
+    # Initialize optimizer
+    opt = Adam(lr=learning_rate)
+
+    # Compile model
+    model.compile(loss='squared_hinge', optimizer=opt, metrics=['accuracy'])
+
+    return model
+
+
+def train_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
 
     callbacks = []
 
@@ -76,11 +77,8 @@ def train_model(model,
     lr_scheduler = LearningRateScheduler(lambda e: lr_start * lr_decay**e)
     callbacks.append(lr_scheduler)
 
-    # Initialize optimizer
-    opt = Adam(lr=lr_start)
-
     # Compile model
-    model.compile(loss='squared_hinge', optimizer=opt, metrics=['accuracy'])
+    model = compile_model(model, lr_start)
 
     # Use data augmentation
     datagen_args = {}
@@ -103,19 +101,10 @@ def train_model(model,
                         callbacks=callbacks)
 
 
-def tune_model(model,
-               x_train,
-               y_train,
-               x_test,
-               y_test,
-               batch_size=500,
-               epochs=100):
-
-    # Initialize optimizer
-    opt = Adam(lr=1e-4)
+def tune_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
 
     # Compile model
-    model.compile(loss='squared_hinge', optimizer=opt, metrics=['accuracy'])
+    model = compile_model(model, 1e-4)
 
     # Early stop when loss has stopped decreasing
     callbacks = []
@@ -136,11 +125,8 @@ def tune_model(model,
 
 def evaluate_model(model, x_test, y_test):
 
-    # Initialize optimizer
-    opt = Adam(lr=1e-4)
-
     # Compile model
-    model.compile(loss='squared_hinge', optimizer=opt, metrics=['accuracy'])
+    model = compile_model(model, 1e-4)
 
     _, accuracy = model.evaluate(x_test, y_test, verbose=0)
     print('Test accuracy:', accuracy)
@@ -152,7 +138,7 @@ def main():
                         "--model",
                         type=str,
                         required=True,
-                        help="Model to be trained or tuned")
+                        help="Model to load")
     parser.add_argument("-s",
                         "--savemodel",
                         type=str,
@@ -177,6 +163,7 @@ def main():
     sp.add_parser(
         "tune",
         help="Tune a pre-trained Keras model (low learning rate, early stop)")
+    sp.add_parser("eval", help="Evaluate a model")
 
     args = parser.parse_args()
 
@@ -194,29 +181,20 @@ def main():
 
     if epochs > 0:
         if args.action == "train":
-            train_model(model,
-                        x_train,
-                        y_train,
-                        x_test,
-                        y_test,
-                        batch_size=args.batch_size,
-                        epochs=epochs)
+            train_model(model, x_train, y_train, x_test, y_test,
+                        args.batch_size, epochs)
         else:
-            tune_model(model,
-                       x_train,
-                       y_train,
-                       x_test,
-                       y_test,
-                       batch_size=args.batch_size,
-                       epochs=epochs)
+            tune_model(model, x_train, y_train, x_test, y_test, args.batch_size,
+                       epochs)
 
-    # Save Model in Keras format (hdf5)
-    if args.savemodel:
-        model.save(args.savemodel, include_optimizer=False)
-        print(f"Trained model saved as {args.savemodel}")
+        # Save Model in Keras format (h5)
+        if args.savemodel:
+            model.save(args.savemodel, include_optimizer=False)
+            print(f"Trained model saved as {args.savemodel}")
 
-    # Evaluate model accuracy
-    evaluate_model(model, x_test, y_test)
+    if args.action == "eval":
+        # Evaluate model accuracy
+        evaluate_model(model, x_test, y_test)
 
 
 if __name__ == "__main__":
