@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,6 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/tse_mlp/'
 
 def tse_mlp_cse2018(numerical_columns=None,
                     categorical_columns=None,
-                    weights=None,
                     weight_quantization=0,
                     activ_quantization=0,
                     input_weight_quantization=None):
@@ -45,8 +44,6 @@ def tse_mlp_cse2018(numerical_columns=None,
         categorical_columns (dict): dictionary of categorical column names
             indexing the list of vocabulary for the column. Will use
             preprocessed data when set to `None`.
-        weights (str): one of `None` (random initialization) or the path to the
-            weights file to be loaded.
         weight_quantization (int): sets MLP weights in the model to have a
             particular quantization bitwidth
 
@@ -73,13 +70,13 @@ def tse_mlp_cse2018(numerical_columns=None,
     labels_mappings = load_labels_mapping()
     n_classes = len(labels_mappings)
 
-    if numerical_columns == None or categorical_columns == None:
+    if numerical_columns is None or categorical_columns is None:
         preprocessed_numerical_columns, preprocessed_categorical_columns = load_columns_type(
         )
 
-    if numerical_columns == None:
+    if numerical_columns is None:
         numerical_columns = preprocessed_numerical_columns
-    if categorical_columns == None:
+    if categorical_columns is None:
         categorical_columns = preprocessed_categorical_columns
 
     mlp_units_list = [128, 128]
@@ -95,13 +92,7 @@ def tse_mlp_cse2018(numerical_columns=None,
                             n_classes,
                             weight_quantization=weight_quantization,
                             activ_quantization=activ_quantization)
-    model = Model(inputs=inputs, outputs=mlp_output)
-
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
-    return model
+    return Model(inputs=inputs, outputs=mlp_output)
 
 
 def tse_mlp_cse2018_pretrained():
@@ -113,9 +104,11 @@ def tse_mlp_cse2018_pretrained():
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'tse_mlp_cse2018_wq2_aq4_iq0.tar.gz'
+    model_name = 'tse_mlp_cse2018_iq0_wq2_aq4.tar.gz'
+    file_hash = '67F49B75B43126A5AFD139EF6BC625329BD7077205C8B24D8A71673BE4EA35D1'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models',
                           extract=True)
     file_path = os.path.join(os.path.dirname(model_path),
