@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,29 +15,26 @@
 # limitations under the License.
 # ******************************************************************************
 
-import os
 import pickle
 
 import numpy as np
 
 from tensorflow.keras import Model
-from tensorflow.keras.layers import Reshape
 from tensorflow.keras.utils import get_file
 
-from ..quantization_blocks import separable_conv_block
+from ..layer_blocks import separable_conv_block
 from ..imagenet.model_mobilenet import mobilenet_imagenet
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize
 
 
-def yolo_base(input_shape,
-              classes,
+def yolo_base(input_shape=(224, 224, 3),
+              classes=1,
               nb_box=5,
               grid_size=(7, 7),
               alpha=1.0,
               dropout=1e-3,
-              weights=None,
               weight_quantization=0,
               activ_quantization=0,
               input_weight_quantization=None):
@@ -50,8 +47,6 @@ def yolo_base(input_shape,
         grid_size (tuple): YOLO grid size tuple
         alpha (float): controls the width of the model
         dropout (float): dropout rate
-        weights (str): `None` (random initialization) or the path to the weights
-         file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -83,7 +78,6 @@ def yolo_base(input_shape,
         alpha=alpha,
         dropout=dropout,
         include_top=False,
-        weights=None,
         weight_quantization=weight_quantization,
         activ_quantization=activ_quantization,
         input_weight_quantization=input_weight_quantization)
@@ -97,8 +91,7 @@ def yolo_base(input_shape,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
+                             add_activation=True,
                              add_batchnorm=True)
     x = separable_conv_block(x,
                              filters=1024,
@@ -106,8 +99,7 @@ def yolo_base(input_shape,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
+                             add_activation=True,
                              add_batchnorm=True)
     x = separable_conv_block(x,
                              filters=1024,
@@ -115,8 +107,7 @@ def yolo_base(input_shape,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
+                             add_activation=True,
                              add_batchnorm=True)
     x = separable_conv_block(x,
                              filters=(nb_box * (4 + 1 + classes)),
@@ -124,8 +115,7 @@ def yolo_base(input_shape,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=True,
-                             activ_quantization=None,
-                             weight_quantization=weight_quantization,
+                             add_activation=False,
                              add_batchnorm=False)
 
     model = Model(inputs=base_model.input, outputs=x, name='yolo_base')
@@ -146,11 +136,12 @@ def yolo_base(input_shape,
 
     layer.set_weights([dw_kernel, pw_kernel, bias])
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0) or
+        (input_weight_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization,
+                        input_weight_quantization)
+    else:
+        return model
 
 
 def yolo_widerface_pretrained():
@@ -171,10 +162,12 @@ def yolo_widerface_pretrained():
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
-    model_name = 'yolo_widerface_wq4_aq4.h5'
+    model_name = 'yolo_widerface_iq8_wq4_aq4.h5'
+    file_hash = '1DE18C1EEBDB1391247ADC6D022114209957D57F43E4A0AF6E4337284058BFF9'
     model_path = get_file(fname=model_name,
                           origin='http://data.brainchip.com/models/yolo/' +
                           model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
 
     return load_quantized_model(model_path), anchors
@@ -198,10 +191,12 @@ def yolo_voc_pretrained():
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
-    model_name = 'yolo_voc_wq4_aq4.h5'
+    model_name = 'yolo_voc_iq8_wq4_aq4.h5'
+    file_hash = '61CCDD20B5891BB2951811423FD125E131687EEA6FE077ECDD21D225539EB3A7'
     model_path = get_file(fname=model_name,
                           origin='http://data.brainchip.com/models/yolo/' +
                           model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
 
     return load_quantized_model(model_path), anchors
