@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@
 # ******************************************************************************
 
 import os
-import pickle
 
 import numpy as np
 import tensorflow as tf
@@ -351,7 +350,6 @@ def parse_widerface_annotations(gt_file, image_folder):
         for line in f:
             file_path = line.rstrip()
             full_file_path = os.path.join(image_folder, str(file_path))
-            file_name = file_path.split('/')[-1]
 
             if not os.path.isfile(full_file_path):
                 raise RuntimeError(f"Not a file path : {full_file_path}")
