@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,24 +15,16 @@
 # limitations under the License.
 # ******************************************************************************
 
-# System imports
-import os
-import warnings
-
 # Tensorflow/Keras Imports
 from tensorflow.keras.utils import get_file
-from tensorflow.keras import backend, Model
-from tensorflow.keras.layers import (Input, BatchNormalization, MaxPool2D,
-                                     GlobalAvgPool2D, Reshape, Dropout,
-                                     Activation)
+from tensorflow.keras import Model
+from tensorflow.keras.layers import Input, Reshape, Dropout, Activation
 
 # cnn2snn Imports
-from cnn2snn import load_quantized_model
-from cnn2snn.quantization_layers import dense
+from cnn2snn import load_quantized_model, quantize
 
 # Local utils
-from ..quantization_blocks import (_add_activation_layer, _get_weight_quantizer,
-                                   conv_block, separable_conv_block)
+from ..layer_blocks import conv_block, separable_conv_block, dense_block
 
 # Locally fixed config options
 # The number of neurons in the penultimate dense layer
@@ -43,8 +35,7 @@ NUM_SPIKING_NEURONS = 256
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
 
 
-def convtiny_dvs_gesture(input_shape,
-                         weights=None,
+def convtiny_dvs_gesture(input_shape=(64, 64, 6),
                          classes=None,
                          weight_quantization=0,
                          activ_quantization=0):
@@ -52,8 +43,6 @@ def convtiny_dvs_gesture(input_shape,
 
     Args:
         input_shape (tuple): input shape tuple of the model
-        weights (str): one of `None` (random initialization) or the path to the
-             pretrained weights or the path to the weights file to be loaded.
         classes (int): number of classes to classify images into.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
@@ -82,8 +71,7 @@ def convtiny_dvs_gesture(input_shape,
                    padding='same',
                    pooling='max',
                    pool_size=(3, 3),
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
+                   add_activation=True,
                    strides=(1, 1))
 
     x = conv_block(x,
@@ -95,8 +83,7 @@ def convtiny_dvs_gesture(input_shape,
                    padding='same',
                    pooling='max',
                    pool_size=(3, 3),
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
+                   add_activation=True,
                    strides=(1, 1))
 
     x = conv_block(x,
@@ -108,8 +95,7 @@ def convtiny_dvs_gesture(input_shape,
                    padding='same',
                    pooling='max',
                    pool_size=(2, 2),
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
+                   add_activation=True,
                    strides=(1, 1))
 
     x = conv_block(x,
@@ -121,8 +107,7 @@ def convtiny_dvs_gesture(input_shape,
                    padding='same',
                    pooling='global_avg',
                    pool_size=(2, 2),
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization,
+                   add_activation=True,
                    strides=(1, 1))
 
     bm_outshape = (1, 1, 128)
@@ -130,18 +115,6 @@ def convtiny_dvs_gesture(input_shape,
     x = Reshape(bm_outshape, name='reshape_1')(x)
     x = Dropout(1e-3, name='dropout')(x)
 
-    aq = 0
-    if weight_quantization > 0:
-        # Assume that if we're quantizing weights, we want the Spiking Layer to
-        # generate spikes
-        aq = 1
-        # Assume that if we're quantizing weights, we want the Dense layer to
-        # be HW compatible, => WQ=2
-        fc_weight_quantizer = _get_weight_quantizer(2)
-    else:
-        aq = activ_quantization
-        fc_weight_quantizer = _get_weight_quantizer(weight_quantization)
-
     x = separable_conv_block(x,
                              filters=NUM_SPIKING_NEURONS,
                              kernel_size=(3, 3),
@@ -149,26 +122,30 @@ def convtiny_dvs_gesture(input_shape,
                              padding='same',
                              name='spiking_layer',
                              add_batchnorm=True,
-                             weight_quantization=weight_quantization,
-                             activ_quantization=aq,
+                             add_activation=True,
                              pooling=None)
 
-    x = dense(classes, modifier=fc_weight_quantizer, use_bias=False)(x)
+    x = dense_block(x,
+                    units=classes,
+                    add_batchnorm=False,
+                    add_activation=False,
+                    use_bias=False)
     x = Activation('softmax', name='act_softmax')(x)
     x = Reshape((classes,), name='reshape_2')(x)
 
     model = Model(inputs=img_input, outputs=x, name='dvs_network')
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization)
+    else:
+        return model
 
 
 def convtiny_gesture_pretrained():
-    model_name = 'convtiny_dvs_gesture_wq2_aq4.h5'
+    model_name = 'convtiny_dvs_gesture_iq2_wq2_aq4.h5'
+    file_hash = '2259AB9B15C63420EE21490CD8CA356B397D165FB0DAC4654BE99D0A8AE9B7BE'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
