@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -168,13 +168,9 @@ def _read_event_v3(file, bytes_pos, trial_times, subj_num, light_cond):
 
         # read header
         type = struct.unpack('H', header[0:2])[0]
-        source = struct.unpack('H', header[2:4])[0]
         size = struct.unpack('I', header[4:8])[0]
-        offset = struct.unpack('I', header[8:12])[0]
         tsoverflow = struct.unpack('I', header[12:16])[0]
         capacity = struct.unpack('I', header[16:20])[0]
-        number = struct.unpack('I', header[20:24])[0]
-        valid = struct.unpack('I', header[24:28])[0]
 
         data_length = capacity * size
         data = file.read(data_length)
@@ -228,7 +224,6 @@ def _read_event_v3(file, bytes_pos, trial_times, subj_num, light_cond):
         else:
             # non-polarity event packet, not implemented
             raise NotImplementedError("Non polarity event packet not supported")
-            pass
     return
 
 
