@@ -1,70 +1,36 @@
 #!/usr/bin/env python
-"""MobileNet v1 models for Keras and Akida
-MobileNet is a general architecture and can be used for multiple use cases.
-(general description from keras.applications still included immediately below).
+# ******************************************************************************
+# Copyright 2020 Brainchip Holdings Ltd.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ******************************************************************************
+"""
+MobileNet V1 is a general architecture and can be used for multiple use cases.
 
-AKIDA
 This specific version includes parameter options to generate a mobilenet version
-with
-- overall architecture compatible with Akida (conv stride 2 replaced with max pool)
-- options to binarize or ternarize both weights and activations
-- options to customize (including remove) batch norm + activation layers
-between the depthwise and pointwise components of the depthwise_conv_block
-- different initialization options
-
-General Mobilenet V1 Notes:
-Depending on the use case, it can use different input layer size and
-different width factors. This allows different width models to reduce
-the number of multiply-adds and thereby
-reduce inference cost on mobile devices.
-MobileNets support any input size greater than 32 x 32, with larger image sizes
-offering better performance.
-The number of parameters and number of multiply-adds
-can be modified by using the `alpha` parameter,
-which increases/decreases the number of filters in each layer.
-By altering the image size and `alpha` parameter,
-all 16 models from the paper can be built, with ImageNet weights provided.
-The paper demonstrates the performance of MobileNets using `alpha` values of
-1.0 (also called 100 % MobileNet), 0.75, 0.5 and 0.25.
-For each of these `alpha` values, weights for 4 different input image sizes
-are provided (224, 192, 160, 128).
-The following table describes the size and accuracy of the 100% MobileNet
-on size 224 x 224:
-----------------------------------------------------------------------------
-Width Multiplier (alpha) | ImageNet Acc |  Multiply-Adds (M) |  Params (M)
-----------------------------------------------------------------------------
-|   1.0 MobileNet-224    |    70.6 %     |        529        |     4.2     |
-|   0.75 MobileNet-224   |    68.4 %     |        325        |     2.6     |
-|   0.50 MobileNet-224   |    63.7 %     |        149        |     1.3     |
-|   0.25 MobileNet-224   |    50.6 %     |        41         |     0.5     |
-----------------------------------------------------------------------------
-The following table describes the performance of
-the 100 % MobileNet on various input sizes:
-------------------------------------------------------------------------
-      Resolution      | ImageNet Acc | Multiply-Adds (M) | Params (M)
-------------------------------------------------------------------------
-|  1.0 MobileNet-224  |    70.6 %    |        529        |     4.2     |
-|  1.0 MobileNet-192  |    69.1 %    |        529        |     4.2     |
-|  1.0 MobileNet-160  |    67.2 %    |        529        |     4.2     |
-|  1.0 MobileNet-128  |    64.4 %    |        529        |     4.2     |
-------------------------------------------------------------------------
-The weights for all 16 models are obtained and translated
-from TensorFlow checkpoints found at
-https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet_v1.md
-# Reference
-- [MobileNets: Efficient Convolutional Neural Networks for
-   Mobile Vision Applications](https://arxiv.org/pdf/1704.04861.pdf))
+compatible for Akida with:
+    - overall architecture compatible with Akida (conv stride 2 replaced with
+     max pool),
+    - options to quantize weights and activations,
+    - different initialization options.
 """
 
-import os
 import warnings
 
 # Tensorflow/Keras Imports
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
-from tensorflow.keras.layers import (Input, BatchNormalization, MaxPool2D,
-                                     GlobalAvgPool2D, Reshape, Dropout,
-                                     Activation)
+from tensorflow.keras.layers import Input, Reshape, Dropout, Activation
 
 # cnn2snn Imports
 from cnn2snn import load_quantized_model, quantize
@@ -128,7 +94,6 @@ def mobilenet_imagenet(input_shape=None,
                        alpha=1.0,
                        dropout=1e-3,
                        include_top=True,
-                       weights=None,
                        pooling=None,
                        classes=1000,
                        weight_quantization=0,
@@ -149,7 +114,6 @@ def mobilenet_imagenet(input_shape=None,
         dropout (float): dropout rate
         include_top (bool): whether to include the fully-connected
             layer at the top of the model.
-        weights (str): the path to the weights file to be loaded.
         pooling (str): Optional pooling mode for feature extraction
             when `include_top` is `False`.
 
@@ -366,10 +330,6 @@ def mobilenet_imagenet(input_shape=None,
                   x,
                   name='mobilenet_%0.2f_%s_%s' % (alpha, rows, classes))
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
     if ((weight_quantization != 0) or (activ_quantization != 0) or
         (input_weight_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization,
@@ -378,18 +338,34 @@ def mobilenet_imagenet(input_shape=None,
         return model
 
 
-def mobilenet_imagenet_pretrained():
+def mobilenet_imagenet_pretrained(alpha=1.0):
     """
     Helper method to retrieve a `mobilenet_imagenet` model that was trained on
     ImageNet dataset.
 
+    Args:
+        alpha (float): width of the model.
+
     Returns:
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'mobilenet_imagenet_iq8_wq4_aq4.h5'
+    if alpha == 1.0:
+        model_name = 'mobilenet_imagenet_iq8_wq4_aq4.h5'
+        file_hash = '07780D7B6A12B764AF1372D792BDF032301508FB997BFD044C397CA2C8AD5747'
+    elif alpha == 0.5:
+        model_name = 'mobilenet_imagenet_alpha_50_iq8_wq4_aq4.h5'
+        file_hash = '7370A0DAA39143280F2CFF55F750162BC6025B2EE1FFC6361347AB295A22818A'
+    elif alpha == 0.25:
+        model_name = 'mobilenet_imagenet_alpha_25_iq8_wq4_aq4.h5'
+        file_hash = '906CB111AAAEB9979D8394D4A33756C439329EDE405041B0BEDD789C570D50B5'
+    else:
+        raise ValueError(
+            f"Requested model with alpha={alpha} is not available.")
+
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
 
@@ -403,8 +379,10 @@ def mobilenet_cats_vs_dogs_pretrained():
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'mobilenet_cats_vs_dogs_wq4_aq4.h5'
+    model_name = 'mobilenet_cats_vs_dogs_iq8_wq4_aq4.h5'
+    file_hash = '85a169b78b426647a7cff3c4d6caf902dcfcb56ea41d5ea50455d7ae466bfdd3'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
