@@ -21,32 +21,18 @@ spike extractor and a classification layer.
 
 It comes with a `mobilenet_edge_imagenet_pretrained` helper method that loads a
 set of pretrained weights on a Mobilenet 0.5 that can be run on Akida hardware.
-
-The following tables describes the expected results using the provided weights:
------------------------------------------------------
-            Model           | Top 1 Acc | Top 5 Acc
------------------------------------------------------
-|  Keras 0.5 MobileNet-224  |   51.5 %  |   76.2 %  |
-|  Akida 0.5 MobileNet-224  |   52.0 %  |   76.4 %  |
-
-# Reference
-
-- [MobileNets: Efficient Convolutional Neural Networks for
-   Mobile Vision Applications](https://arxiv.org/pdf/1704.04861.pdf))
-
 """
-import os
 
 # Tensorflow/Keras imports
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
-from tensorflow.keras.layers import Reshape, Dropout, Activation
+from tensorflow.keras.layers import Reshape, Activation
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize_layer
 
 # Local utils
-from ..quantization_blocks import separable_conv_block, dense_block
+from ..layer_blocks import separable_conv_block, dense_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/mobilenet_edge/'
 
@@ -64,8 +50,6 @@ def mobilenet_edge_imagenet(base_model, classes):
     if isinstance(base_model, str):
         base_model = load_quantized_model(base_model)
 
-    input_shape = base_model.input_shape
-
     try:
         # Identify the last separable, which is the base model classifier
         base_classifier = base_model.get_layer("separable_14")
@@ -86,32 +70,39 @@ def mobilenet_edge_imagenet(base_model, classes):
                              use_bias=False,
                              add_batchnorm=True,
                              name='spike_generator',
-                             weight_quantization=wq,
-                             activ_quantization=1)
+                             add_activation=True)
 
     # Then add the Akida edge learning layer that will be dropped after
-    # NOTE: weight_quantization set to 2 here, to be as close as
-    # possible to the Akida native layer that will replace this one,
-    # with binary weights.
     x = dense_block(x,
                     classes,
                     name="classification_layer",
-                    weight_quantization=2,
-                    activ_quantization=None,
+                    add_activation=False,
                     add_batchnorm=False,
                     use_bias=False)
     x = Activation('softmax', name='act_softmax')(x)
     x = Reshape((classes,), name='reshape_2')(x)
 
     # Create model
-    return Model(inputs=base_model.input,
-                 outputs=x,
-                 name=f"{base_model.name}_edge")
+    model = Model(inputs=base_model.input,
+                  outputs=x,
+                  name=f"{base_model.name}_edge")
+
+    # Quantize edge layers
+    model = quantize_layer(model, 'spike_generator', wq)
+    model = quantize_layer(model, 'spike_generator_relu', 1)
+    # NOTE: quantization set to 2 here, to be as close as
+    # possible to the Akida native layer that will replace this one,
+    # with binary weights.
+    model = quantize_layer(model, 'classification_layer', 2)
+
+    return model
 
 
 def mobilenet_edge_imagenet_pretrained():
-    model_name = 'mobilenet_imagenet_edge_wq4_aq4.h5'
+    model_name = 'mobilenet_imagenet_alpha_50_edge_iq8_wq4_aq4.h5'
+    file_hash = '707B9061CF60EC38D17ABF60AFFA0108E5B8C7E58F076347490ADEC2685F7A0D'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
