@@ -26,7 +26,6 @@ is originated from https://github.com/bckenstler/CLR and is under MIT license.
 
 # System imports
 import os
-import sys
 import argparse
 import pickle
 
@@ -63,6 +62,15 @@ def get_rescaled_dataset(a, b):
     return x_train_keras, y_train, x_val_keras, y_val
 
 
+def compile_model(model, learning_rate=1e-4):
+    # Initialize optimizer and compile model
+    opt = Adam(lr=learning_rate)
+    model.compile(loss='categorical_crossentropy',
+                  optimizer=opt,
+                  metrics=['accuracy'])
+    return model
+
+
 def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
     # Warn user if number of epochs is not a multiple of 8
     if epochs % 8:
@@ -83,10 +91,7 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
     callbacks.append(clr)
 
     # Compile model
-    opt = Adam(lr=max_lr)
-    model.compile(loss='categorical_crossentropy',
-                  optimizer=opt,
-                  metrics=['accuracy'])
+    model = compile_model(model, max_lr)
 
     model.fit(x_train,
               to_categorical(y_train),
@@ -98,15 +103,7 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
 
 
 def evaluate_model(model, x_val, y_val):
-
-    # Initialize optimizer
-    opt = Adam(lr=1e-4)
-
-    # Compile model
-    model.compile(loss='categorical_crossentropy',
-                  optimizer=opt,
-                  metrics=['accuracy'])
-
+    model = compile_model(model)
     _, accuracy = model.evaluate(x_val, to_categorical(y_val), verbose=0)
     print('Validation accuracy:', accuracy)
 
@@ -117,7 +114,7 @@ def main():
                         "--model",
                         type=str,
                         required=True,
-                        help="Model to be trained")
+                        help="Model to load")
     parser.add_argument("-s",
                         "--save_model",
                         type=str,
@@ -138,6 +135,11 @@ def main():
                         type=int,
                         default=100,
                         help="The training batch size")
+
+    sp = parser.add_subparsers(dest="action")
+    sp.add_parser("train", help="Train a Keras model")
+    sp.add_parser("eval", help="Evaluate a model")
+
     args = parser.parse_args()
 
     # Input scaling
@@ -164,18 +166,18 @@ def main():
     batch_size = args.batch_size
     epochs = args.epochs
 
-    if epochs > 0:
-        train_model(model,
-                    x_train,
-                    y_train,
-                    x_val,
-                    y_val,
-                    batch_size=batch_size,
-                    epochs=epochs)
+    # Train model
+    if epochs > 0 and args.action == "train":
+        train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs)
 
-    # Save Model in Keras format (h5)
-    if args.save_model:
-        model.save(args.save_model, include_optimizer=False)
+        # Save model in Keras format (h5)
+        if args.save_model:
+            model.save(args.save_model, include_optimizer=False)
 
-    # Evaluate model accuracy
-    evaluate_model(model, x_val, y_val)
+    if args.action == "eval":
+        # Evaluate model accuracy
+        evaluate_model(model, x_val, y_val)
+
+
+if __name__ == "__main__":
+    main()
