@@ -15,8 +15,6 @@
 # limitations under the License.
 # ******************************************************************************
 
-import os
-
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Input, Reshape, Activation, Flatten
 from tensorflow.keras.utils import get_file
@@ -32,7 +30,6 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/ds_cnn/'
 def ds_cnn_kws(input_shape=(49, 10, 1),
                classes=33,
                include_top=True,
-               weights=None,
                weight_quantization=0,
                activ_quantization=0,
                input_weight_quantization=None,
@@ -53,8 +50,6 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
             be specified if `include_top` is True.
         include_top (bool): whether to include the fully-connected
             layer at the top of the model.
-        weights (str): one of `None` (random initialization) or the path to the
-            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -165,10 +160,6 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
 
     model = Model(img_input, x, name='ds_cnn_kws')
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
     if ((weight_quantization != 0) or (activ_quantization != 0) or
         (input_weight_quantization != 0)):
         # Converts a standard sequential Keras model to a CNN2SNN Keras
@@ -198,7 +189,9 @@ def ds_cnn_kws_pretrained():
 
     """
     model_name = 'ds_cnn_kws_iq8_wq4_aq4_laq1.h5'
+    file_hash = 'A26240D2E284B7ECD2634F8CD77366C0A4C7BD4F39E4BDE4AA7D14D5D860E09E'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
